package com.zanxiang.sdk.controller;

import com.zanxiang.common.domain.ResultVo;
import com.zanxiang.sdk.domain.params.*;
import com.zanxiang.sdk.domain.vo.UserLoginVO;
import com.zanxiang.sdk.service.IUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * @author : lingfeng
 * @time : 2022-06-16
 * @description : 用户接口
 */
@Api(tags = "用户接口")
@CrossOrigin
@RestController
@RequestMapping(value = "/api/user")
public class UserController {

    @Autowired
    private IUserService userService;

    @ApiOperation(value = "用户普通注册")
    @PostMapping("/register/password")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo<UserLoginVO> registerPassword(@Validated @RequestBody RegisterPasswordParam registerPasswordParam,
                                                  HttpServletRequest request) {
        return userService.registerPassword(registerPasswordParam, request);
    }

    @ApiOperation(value = "用户手机注册")
    @PostMapping("/register/mobile")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo<UserLoginVO> registerMobile(@Validated @RequestBody RegisterMobileParam registerMobileParam,
                                                HttpServletRequest request) {
        return userService.registerMobile(registerMobileParam, request);
    }

    @ApiOperation(value = "用户名密码登录")
    @PostMapping("/login/password")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo<UserLoginVO> loginPassword(@Validated @RequestBody LoginPasswordParam userLoginParam, HttpServletRequest request) {
        return userService.loginPassword(userLoginParam, request);
    }

    @ApiOperation(value = "用户手机号登录")
    @PostMapping("/login/mobile")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo<UserLoginVO> loginMobile(@Validated @RequestBody LoginMobileParam loginMobileParam, HttpServletRequest request) {
        return userService.loginMobile(loginMobileParam, request);
    }

    @ApiOperation(value = "用户重置密码")
    @PostMapping("/update/password")
    @ApiResponses(value = {@ApiResponse(code = 200, message = "成功", response = UserLoginVO.class)})
    public ResultVo updatePassword(@Validated @RequestBody UpdatePasswordParam updatePasswordParam) {
        return userService.updatePassword(updatePasswordParam);
    }
}
